A shiny Module. This module combines the tree with genetic distance as an tidytree object that allows tree plotting and accessing the combined data. This module contains 1 function at the end of the script that is used within (tree_plot). The tree_plot function allows for various parameters to be changed dynaically on the tree image. This module also uses one function in the golem_utils_server file (combine_g_and_t), which combines the tree and genetic distance matrix that has already been transformed with the meta data file.
mod_displayTree_ui(id) mod_displayTree_server( input, output, session, tree_file_out, geneObjectOutForSNP, align, tree_format, font, num_scale, node, lim, boot_pos, mid_p, mat_off )
| id | shiny id |
|---|---|
| input | internal |
| output | internal |
| session | internal |
| tree_file_out | - from upload/example Data module. class of phylo |
| geneObjectOutForSNP | - from upload/example Data module. class of "spec_tbl_df", "tbl_df", "tbl", and "data.frame" #' @param align - from paramsTree module; this is checkbox input (Y or N) |
| tree_format | - from paramsTree module; checkbox input (multiple choice) |
| font | - from paramsTree module; checkbox input (multiple choice) |
| num_scale | - from paramsTree module; this is numeric input from user |
| node | - from paramsTree module; this is numeric input from user |
| lim | - from paramsTree module; this is numeric input from user |
| boot_pos | - from paramsTree module; this is numeric input from user |
| mid_p | - from paramsTree module; this is checkbox input (Y or N) |
| mat_off | - from paramsTree module; this is numeric input from user |
displayTree Function