A shiny Module. This module generates messages for the user regarding the files uploaded and if column(s) for a heatmap is available. This module contains 3 functions located in the golem_utils_server file (sanity, not_columns, and m_file_conversion). Essentially. these functions are used for checking or converting files for downstream analyses.
mod_tipCheck_ui(id) mod_tipCheck_server( input, output, session, meta_file_out, m_file_out, gene_file_out, g_file_out, t_file_out, tree_file_out )
| id, input, output, session | internal |
|---|---|
| meta_file_out | used to confirm that file is uploaded; on/off |
| m_file_out | meta data that is read in used file for tip checking |
| gene_file_out | used to confirm that file is uploaded; on/off |
| g_file_out | gene data that is read in used for tip checking |
| t_file_out | tree data that is read in for tip checking |
| tree_file_out | used to confirm that file is uploaded; on/off |
tipCheck Function